Index: src/compiler/interpreter-assembler.h |
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h |
index b7ea4385f87d281e4d786e1d47ff848900a11eab..ead7b92d7aa8b6792398e0308ece8cdf844c4f7b 100644 |
--- a/src/compiler/interpreter-assembler.h |
+++ b/src/compiler/interpreter-assembler.h |
@@ -43,8 +43,8 @@ class InterpreterAssembler { |
Node* NumberConstant(double value); |
Node* HeapConstant(Unique<HeapObject> object); |
- // Returns the bytecode argument |index| for the current bytecode. |
- Node* BytecodeArg(int index); |
+ // Returns the bytecode operand |index| for the current bytecode. |
+ Node* BytecodeOperand(int index); |
// Loads from and stores to the interpreter register file. |
Node* LoadRegister(int index); |